<center><img src="https://raw.githubusercontent.com/colav/colav.github.io/master/img/Logo.png"/></center>

# HunabKu openscienti plugin 
Provides API for Scienti Open Data downloaded from www.datos.gov.co
Using https://github.com/colav/Yuku/ package.



# Installation

## Package
Write here how to install this plugin
usauly is 

`pip install hunabku_openscienti`


# License
BSD-3-Clause License 

# Links
http://colav.udea.edu.co/



